BridgeParameter class

Describes a parameter of a bridged function.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BridgeParameter(String name, BridgeTypeAnnotation type, bool optional)
const
BridgeParameter.fromJson(Map<String, dynamic> json)
Connect the generated _$BridgeParameterFromJson function to the fromJson factory.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the parameter.
final
optional → bool
Whether the parameter is optional
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → BridgeTypeAnnotation
The type of the parameter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Connect the generated _$BridgeParameterToJson function to the toJson method.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited