DartSource class

A unit of Dart source code, from a file or String.

Implementers

Constructors

DartSource(String uri, String source)
DartSource.file(String uri, File file)

Properties

fileSource → File?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringSource → String?
final
uri → Uri
A package, dart, or file URI
final

Methods

load(DiagnosticMode diagnosticMode) → DartCompilationUnit
Load the source code from the filesystem or a String and parse it (internally using parseString from the Dart analyzer) into an AST
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override