$Duration class

dart_eval bimodal wrapper for Duration

Implemented types

Constructors

$Duration.wrap(Duration $value)
Wrap a Duration in a $Duration

Properties

$reified Duration
Fully reify the underlying value so it can be used in a Dart context. For example, recursively transform collections into their underlying $values.
no setteroverride
$value Duration
The backing Dart value of this $Value.
final
hashCode int
The hash code for this object.
no setterinherited
inDays int
The number of entire days spanned by this Duration.
no setteroverride
inHours int
The number of entire hours spanned by this Duration.
no setteroverride
inMicroseconds int
The time offset of this duration in microseconds.
no setteroverride
inMilliseconds int
The number of whole milliseconds spanned by this Duration.
no setteroverride
inMinutes int
The number of whole minutes spanned by this Duration.
no setteroverride
inSeconds int
The number of whole seconds spanned by this Duration.
no setteroverride
isNegative bool
Whether this Duration is negative.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$getProperty(Runtime runtime, String identifier) $Value?
Get a property by identifier on this instance
override
$getRuntimeType(Runtime runtime) int
Index of the class Type in the runtime dictionary. By definition can change from run to run, so it's customary to use Runtime.lookupType in implementations.
override
$setProperty(Runtime runtime, String identifier, $Value value) → void
Set a property by identifier on this instance to value
override
abs() Duration
A positive Duration with the same absolute length as this Duration.
override
compareTo(Duration other) int
Compares this Duration to other.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator *(num factor) Duration
This Duration scaled by factor.
override
operator +(Duration other) Duration
Adds this Duration and other and returns the sum as a new Duration object.
override
operator -(Duration other) Duration
The offset of this duration minus the offset of other.
override
operator <(Duration other) bool
Whether this duration's offset is smaller than that of other.
override
operator <=(Duration other) bool
Whether this duration's offset is not greater than that of other.
override
operator ==(Object other) bool
The equality operator.
inherited
operator >(Duration other) bool
Whether this duration's offset is greater than that of other.
override
operator >=(Duration other) bool
Whether this duration's offset is not smaller than that of other.
override
operator unary-() Duration
The offset of this duration minus the offset of other.
override
operator ~/(int quotient) Duration
One-quotientth of this duration.
override

Static Methods

configureForRuntime(Runtime runtime) → void

Constants

$declaration → const BridgeClassDef
Compile-time class declaration for $Duration
$type → const BridgeTypeRef
Compile-time type definition for $Duration