abs method

  1. @override
Duration abs()
override

A positive Duration with the same absolute length as this Duration.

The returned Duration has the same length as this one, but is always positive where possible.

Implementation

@override
Duration abs() => $value.abs();