operator >= method

  1. @override
bool operator >=(
  1. Duration other
)
override

Whether this duration's offset is not smaller than that of other.

A negative duration's offset is always smaller than a positive one's. Equivalent to comparing inMicroseconds

Implementation

@override
bool operator >=(Duration other) => $value >= other;