$reified property

  1. @override
Map get $reified
override

Fully reify the underlying value so it can be used in a Dart context. For example, recursively transform collections into their underlying $values.

Implementation

@override
Map get $reified => $value.map(
  (k, v) =>
      MapEntry(k is $Value ? k.$reified : k, v is $Value ? v.$reified : v),
);