A positive Duration with the same absolute length as this Duration.
The returned Duration has the same length as this one, but is always positive where possible.
@override Duration abs() => $value.abs();