operator ~/ method
One-quotientth of this duration.
Divides the offset in microseconds of this duration by quotient
rounding towards zero, and provides a new Duration with that
as its inMicroseconds.
The quotient must not be 0. If it is negative, the result
is equivalent to dividing by the absolute value and then negating.
Implementation
@override
Duration operator ~/(int quotient) => $value ~/ quotient;